#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unix-time
version:              0.4.17
visibility:           public
id:                   unix-time-0.4.17-3UoKvzABwiy2TOGfyowAb9
key:                  unix-time-0.4.17-3UoKvzABwiy2TOGfyowAb9
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Unix time parser/formatter and utilities
description:          Fast parser\/formatter\/utilities for Unix time
category:             Data
abi:                  dcc99e164f08d3b88e2fe121872f66e5
exposed:              True
exposed-modules:      Data.UnixTime
hidden-modules:
    Data.UnixTime.Conv Data.UnixTime.Diff Data.UnixTime.Types
    Data.UnixTime.Sys

import-dirs:          /usr/lib/ghc-9.6.6/site-local/unix-time-0.4.17
library-dirs:         /usr/lib/ghc-9.6.6/site-local/unix-time-0.4.17
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/unix-time-0.4.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unix-time
hs-libraries:         HSunix-time-0.4.17-3UoKvzABwiy2TOGfyowAb9
depends:
    base-4.18.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    old-time-1.1.0.5-6pAIdwhrU2yDlFeoj1dxmG

haddock-interfaces:   /usr/share/doc/haskell-unix-time/html/unix-time.haddock
haddock-html:         /usr/share/doc/haskell-unix-time/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

